drop table events cascade constraints;
drop table eventinfo;
drop table eventtimes;
drop table eventsponsor;
drop table country cascade constraints;
drop table state cascade constraints;
drop table city cascade constraints;
drop table building cascade constraints;
drop table location;
drop view  eventview;
drop view  eventplace;


CREATE TABLE country (
  countryid   number(3) primary key not null,
  countryname varchar2(80) unique not null,
  isotwo      char(2) unique not null,
  isothree    char(3) unique not null
);


CREATE TABLE state (
  stateid      number(6) primary key not null,
  countryid    number(3) not null REFERENCES country(countryid),
  statename    varchar2(80)
);

CREATE TABLE city (
  cityid        number(8) primary key not null,
  stateid       number(6) not null REFERENCES state(stateid),
  city          varchar2(80)
);

CREATE TABLE building (
  buildingid     number(8) primary key not null,
  cityid         number(8)  not null references city(cityid),
  building       varchar2(80), 
  address        varchar2(80) not null,
  postalcode     varchar2(40) not null,
  unique (building, cityid)
);

CREATE TABLE location (
  loccode     number(8) primary key,
  buildingid  number(8) not null REFERENCES building(buildingid),
  room        varchar2(80)
);



CREATE TABLE events (
  eventid   number(8) primary key not null,
  title     varchar2(80) unique not null,
  category  varchar2(20) not null,
  costlevel number(5),
  costdesc  varchar2(80),
  loccode   number(8) not NULL REFERENCES location(loccode),
  moreinfo  varchar2(80)
);

CREATE INDEX eventsloccodeix on events(loccode);


CREATE TABLE eventtimes (
  eventid number(8) not null REFERENCES events(eventid),
  edate   date,
  time    char(8),
  length  number(5)
);  

CREATE INDEX eventtimesix ON eventtimes(eventid);

CREATE TABLE eventinfo (
  eventid number(8) primary key not null REFERENCES events(eventid),
  about   long
);



rem -----------------------------------------------------------------------

CREATE VIEW eventplace (loccode, building, room, address, city, postalcode) as
       select loccode, building, room, address, city, postalcode from
              location, building, city where
              location.buildingid = building.buildingid and
              building.cityid     = city.cityid;               



rem -----------------------------------------------------------------------

CREATE VIEW eventinserter (title, category, costlevel, costdesc, building,
			   room, moreinfo, edate, time, length)
                           AS
            SELECT title, category, costlevel, costdesc, building, room,
		   moreinfo, edate, time, length
            FROM   events, eventtimes, eventinfo, eventplace, eventinfo;

rem -----------------------------------------------------------------------

CREATE VIEW eventview (eventid, title, category, costlevel, costdesc, building,
		       room, address, city, moreinfo, edate, time, length)
		       as
		select distinct events.eventid, title, category, costlevel,
		       costdesc, building,
		       room, address, city, moreinfo, edate, time, length
		       from events, eventtimes, eventinfo, eventplace
                       where
                        events.eventid = eventtimes.eventid and
                        events.loccode = eventplace.loccode;
rem -----------------------------------------------------------------------

insert into country values(1, 'United States of America', 'US', 'USA');
insert into country values(2, 'Canada', 'CA', 'CAN');

insert into state values(1, 1, 'Minnesota');
insert into state values(2, 1, 'Wisconsin');

insert into city  values(1, 1, 'Minneapolis');
insert into city  values(2, 1, 'St. Paul');


rem -----------------------------------------------------------------------

insert into building values (1, 1, 'Calhoun Square', '3001 S. Hennepin Ave.', 
                             '55408');
insert into building values (2, 1, 'Walker Art Center', '725 Vineland Pl.',
			     '55405');
insert into building values (3, 1, 'Hubert H. Humprey Metrodome',
 			     '501 S. Chicago Ave.', '55401');
insert into building values (4, 1, 'Target Center', '600 N. First Ave.',
                             '55405');
insert into building values (5, 1, 'Uptown Bar and Grill', 
			     '3018 Hennepin Ave. S.', '55408');
insert into building values (6, 1, 'First Avenue', '701 First Ave. N.',
			     '55401');
insert into building values (7, 2, 'St. Paul Student Center', 
		             '2017 Buford Ave.', '55108');
insert into building values (8, 1, 'Eddy Hall', '192 Pillsbury Dr. S.E.',
			     '55455');
insert into building values (9, 1, 'Coffman Memorial Union',
			     '1500 Washington Ave. S.E.', '55455');
insert into building values (10, 1, 'Northrup Auditorium', 
			     '84 Church St. S.E.', '55455');
insert into building values (11, 1, 'Hubert H. Humphrey Center',
			     '301 19th Ave. S.E.', '55455');
insert into building values (12, 1, 'Ted Mann Concert Hall', 'xx',
			     '55455');
insert into building values (13, 1, '7th Street Entry', '29 N. Seventh St.',
			     '55401');
insert into building values (14, 2, 'Hungry Mind Bookstore',
			     '1648 Grand Ave.', '55105');
insert into building values (15, 1, 'Weisman Museum', '333 E. River Rd.',
			     '55455');


insert into location values (1, 1, 'Borders Book Shop');
insert into location values (2, 2, 'Gallery 8 Restaurant');
insert into location values (3, 3, 'Stadium');
insert into location values (4, 4, 'Main Arena');
insert into location values (5, 5, 'Stage');
insert into location values (6, 2, 'Auditorium');
insert into location values (7, 6, 'Main Room');
insert into location values (8, 7, 'North Star Ballroom');
insert into location values (9, 8, '#109');
insert into location values (10, 9, 'The Whole, room B1');
insert into location values (11, 10, 'Main Auditorium');
insert into location values (12, 11, 'Cowles Auditorium');
insert into location values (13, 9, 'Great Hall');
insert into location values (14, 12, 'Main Auditorium');
insert into location values (15, 9, 'Theater');
insert into location values (16, 9, 'Commuter Lounge');
insert into location values (17, 13, 'Stage');
insert into location values (18, 7, 'Theater');
insert into location values (19, 14, 'Main Floor');
insert into location values (20, 15, 'Lobby');
insert into location values (21, 7, 'Terrace Cafe');
insert into location values (22, 7, 'Lower Level Lounge');
insert into location values (23, 15, 'William G. Shepherd Room');

rem -----------------------------------------------------------------------

insert into events values (1,'The Hang Ups with Saucer and Alligator Gun',
'CONCERT', 5,'$4 Students, $5 Others', 10,
'Call 624-5105');

insert into eventtimes values(1, '22-Oct-93', '8:30pm', 240);


insert into events values(2,'PERSI DIACONIS -- ON COINCIDENCES',
'LECTURE', 0, 'Free', 11, 
'call (612) 625-5591 or contact dept@math.umn.edu');

insert into eventtimes values(2, '9-Nov-93', '4:00pm', 60);


insert into events values(3,'Silha Lecture - L.D. Boccardi',
'LECTURE', 0,'Free', 12,
'call 625-3421');

insert into eventtimes values(3, '19-Oct-93', '12:15pm', 60);


insert into events values(4,'New Art Museums Conference',
'CONFERENCE', 0, 'Free, reservations required', 13,
'call 624-6053 for information and reservations'); 

insert into eventtimes values(4, '10-Dec-93', '9:00am', 480);
insert into eventtimes values(4, '11-Dec-93', '9:00am', 480);


insert into events values(5,'American Indian Dance Theatre',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(5, '6-Nov-93', '8:00pm', 120);


insert into events values(6,'Amanda Miller Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(6, '20-Nov-93', '8:00pm', 120);


insert into events values(7,'Dance Theatre of Harlem',
'DANCE', 20, 'Tickets: $19.50, $14.50, $9.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(7, '11-Feb-94', '8:00pm', 120);
insert into eventtimes values(7, '12-Feb-94', '8:00pm', 120);


insert into events values(9,'Principal Dancers of New York City Ballet',
'DANCE', 26, 'Tickets: $33.50, $25.50, $19.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(9, '8-Mar-94', '8:00pm', 120);
insert into eventtimes values(9, '9-Mar-94', '8:00pm', 120);

insert into events values(10, 'Bebe Miller Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(10, '19-Mar-94', '8:00pm', 120);


insert into events values(11, 'Paul Taylor Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
11, 'Northrup Ticket Office 624-2345');

insert into eventtimes values(11, '24-Mar-94', '8:00pm', 120);



insert into events values(12, 'Julius Hemphill', 'DANCE', 15, 
'Tickets: $15.00, $13.00, $11.00', 14, 'Northrup Ticket Office 624-2345');
insert into eventtimes values(12, '6-Apr-94', '8:00pm', 120);

insert into events values(13, 'Microsoft Presentation',
'LECTURE', 0, 'Free',
15, 'call 626-9816');

insert into eventtimes values(13, '22-Oct-93', '8:00pm', 120);


insert into events values(14, 'Drunk Driving Awareness Day: Root Beer Keg',
'EVENT', 0, 'Free',
16, '');
insert into eventtimes values(14, '10-Nov-93', '11:00am', 120);
insert into eventtimes values(14, '10-Nov-93', '4:00pm', 120);


insert into events values(15, 'Myers-Brigg Type Indicator Test',
'SPECIAL EVENT', 4, 'Fee of $3.50', 9, '');
insert into eventtimes values(15, '3-Nov-93', '2:30pm', 60);
insert into eventtimes values(15, '10-Nov-93', '2:30pm', 60);


insert into events values(16, 'Ski Swap Sale',
'FAIR', 0, 'Free', 8, '');
insert into eventtimes values(16, '10-Nov-93', '9:00am',660);

insert into events values(17, 'Cracker/Rex Daisy/Counting Crows',
'CONCERT', 7, '$6 Advance, $8 Door', 7, 'call 338-8388');
insert into eventtimes values(17, '3-Nov-93', '6:00pm', 180);

insert into events values(18, 'The Remains of the Day - Special Screening',
'FILM', 6, '$5 Walker members, $6 nonmembers', 6, 'call 375-7622');
insert into eventtimes values(18,'3-Nov-93','8:00pm', 90);

insert into events values(19, 'Didjits/Pegboy',
'CONCERT', 3, '$3 Cover', 5, 'call 823-4719');
insert into eventtimes values(19,'7-Nov-93','9:00pm', 240);

insert into events values(20, 'Robert Plant/Cry of Love',
'CONCERT', 27, 'Tickets: $22.50-$32.50', 11,
'call 989-5151 (Ticketmaster)');
insert into eventtimes values(20, '8-Nov-93', '7:30pm', 240);

insert into events values(21, 'Minnesota Timberwolves vs. Utah Jazz',
'SPORTS', 15, 'ticket prices vary', 4 ,
'call 989-5151 (Ticketmaster)');
insert into eventtimes values(21, '6-Nov-93', '7:00pm', 120);

insert into events values(22, 'Minnesota Vikings vs. San Diego',
'SPORTS', 20, 'ticket prices vary', 3,
'call 825-DOME or 989-5151');
insert into eventtimes values(22, '7-Nov-93', '12:00pm', 120);

insert into events values(23, 'Squeeze with Over the Rhine',
'CONCERT', 5, 'tickets $5', 7, 'call 338-8388');
insert into eventtimes values(23, '7-Nov-93', '8:00pm', 300);

insert into events values(24, 'Joe Paddock Reading',
'READING', 0, 'Free', 2, 'call 825-0336');
insert into eventtimes values(24, '3-Nov-93', '7:30pm', 60);

insert into events values(25, 'Sarah Shulman, "Empathy" Reading',
'READING', 0, 'Free', 1, 'call 375-7622');
insert into eventtimes values(25, '3-Nov-93', '8:00pm', 60);

insert into events values(26, 'Ike Reilly and Community #9',
'CONCERT', 4, '$4 Cover', 17, 'Call 338-8388');
insert into eventtimes values(26, '24-Feb-94', '8:00pm', 300);

insert into events values(27, 'Universal VIBE Squad', 'CONCERT',
0, 'Free', 10, 'Call 626-2380');
insert into eventtimes values(27, '24-Feb-94', '7:00pm', 120);

insert into events values(28, 'The Wedding Banquet', 'FILM',
2, '$2 students, $3 general', 18, 'Call 624-3742');
insert into eventtimes values(28, '24-Feb-94', '7:00pm', 120);
insert into eventtimes values(28, '25-Feb-94', '7:00pm', 120);
insert into eventtimes values(28, '25-Feb-94', '9:30pm', 120);

insert into events values(29, 'Chris Offutt', 'READING',
0, 'Free', 19, 'Call 699-0587');
insert into eventtimes values(29, '24-Feb-94', '8:00pm', 60);

insert into events values(30, 
'On the Road with Jim Jarmusch -- Night on Earth', 'FILM', 6, 
'$6 General, $5 Members', 6, 'Call 375-7622');
insert into eventtimes values(29, '23-Feb-94', '7:00pm', 90);

insert into events values(31, 
'On the Road with Jim Jarmusch', 'FILM', 6,
'$6 General, $5 Members', 6, 'Call 375-7622');
insert into eventtimes values(30, '25-Feb-94', '7:00pm', 90);
insert into eventtimes values(30, '25-Feb-94', '9:15pm', 90);

insert into events values(32,
'Late Night in Gallery 8 - Eric Belgum', 'CONCERT', 5,
'$5 General, $4 Members', 1, 'Call 375-7622');
insert into eventtimes values (32, '26-Feb-94', '10:00pm', 90);

insert into events values(33, 
'Arcwelder', 'CONCERT', 7, '$7 Cover', 5, 'call 823-4719');
insert into eventtimes values(33, '26-Feb-94', '9:00pm', 240);

insert into events values(34, 
'Roy Lichtenstein:  film biography about the pop artist', 'FILM', 
0, 'Free', 20, '');
insert into eventtimes values(34, '2-Mar-94', '3:30pm', 90);

insert into events values(35,
'Phillip Glass', 'CONCERT', 13, 'Individual Tickets: $15.00, $13.00, $11.00',
14, 'Call Northrup Ticket Office: 624-2345');
insert into eventtimes values(35, '27-Apr-94', '8:00pm', 90);

insert into events values(36,
'Miami City Ballet', 'DANCE', 23, 'Individual Tickets: $28.50, $22.50, $16.50',
11, 'Call Northrup Ticket Office: 624-2345');
insert into eventtimes values(36, '12-Apr-94', '8:00pm', 90);
insert into eventtimes values(36, '13-Apr-94', '8:00pm', 90);

insert into events values(37,
'Simon Widdowson  British folk rock', 'CONCERT', 0, 'Free', 21,
'Call 624-3742');
insert into eventtimes values(37, '2-Mar-94, '12:00pm', 60);

insert into events values(38,
'Wildlife Calling Contest', 'SPECIAL EVENT', 0, 'Free', 21,
'Call 624-3742');
insert into eventtimes values(38, '3-Mar-94', '12:00pm', 60);

insert into events values(39,
'Seth Roback  Romantic anti-folk guitar', 'CONCERT', 0, 'Free', 21,
'Call 624-3742');
insert into eventtimes values(39, '9-Mar-94', '12:00pm', 60);

insert into events values(40,
'Vegetarian Cooking', 'SPECIAL EVENT', 0, 'Free', 22, '');
insert into eventtimes values(40, '8-Mar-94', '12:00pm', 60);

insert into events values(41, 
'Eileen Mc Gann.  Celtic form of inspired folk music', 'CONCERT', 7,
'Students $5, non-students $9, at door $10', 18, 'Go to Union Station');
insert into eventtimes values(41, '5-Mar-94', '7:30pm', 120);

insert into events values(42,
'James Keeleghan. Canadian history songwriter', 'CONCERT', 7,
'Students $5, non-students $9, at door $10', 18, 'Go to Union Station');
insert into eventtimes values(42, '11-Mar-94', '7:30pm', 120);

insert into events values(43,
'Taking Chances: Creativity at the University - Physics as an Art Form', 'LECTURE',
0, 'Free', 23, '');
insert into eventtimes values(43, '13-Mar-94', '2:00pm', 90);

insert into events values(44,
'Gene Logsdon', 'READING', 0, 'Free', 19, 'Call 699-0587');
insert into eventtimes values(44, '1-Mar-94', '8:00pm', 60);


rem -----------------------------------------------------------------

insert into eventinfo values (
44, 
'Reading from "At Nature''s Pace" (Pantheon, $23), a series of insightful
essays on the decline of rural society.
');

insert into eventinfo values (
43,
'Presented by Roger Jones, associate professor of physics, University 
of Minnesota.
-
"Taking Chances: Creativity at the University"
-
Frank Gehry''s design for the Frederick R. Weisman Art Museum embodies the 
lively spirit of fresh thinking and risk-taking that is at the heart of 
university research, teaching, and learning at its best.  Creative thought is 
critical to all endeavors, not only to the arts, which are often considered 
the major locus of creativity.  "Taking Chances: Creativity at the University" 
will promote knowledge about the creative process itself, as it occurs across 
cultures, age groups, occupations, activities, and disciplines.
');


insert into eventinfo values (
33,
'This is the first show Arcwelder has done in some time, so show up
early.'
);

insert into eventinfo values (
32,
'Local composer Eric Belgum hosts an evening of text pieces and electronic
music.  This is the first of three late-night concerts focusing on
unconventional musicmaking that will be copresented by the Walker and the
Minnesota Composers Forum'
);

insert into eventinfo values (
31,
'Rock-and-roll obsessed Japanese tourists, visions of Elvis, and minor
mayhem are subjects of three seemingly unrelated stories that unfold in 
Memphis all on the same night.  Screened with two music videos Jarmusch
created for Tom Waits.
');

insert into eventinfo values (
30, 
'Jarmusch''s most recent feature is an anthology of five
different encounters that all take place in taxicabs and that all occur 
on the same night in five different American and European cities.
With Gena Rowlands, Winona Ryder, Rosie Perez.
');


insert into eventinfo values(
29, 
'Offutt read from his memoir, "The Same River Twice", about his search
for self and rocky transition into fatherhood after being rejected by the
army, the Peace Corps, the park rangers and the police.  There''s a 
fresh idea: If you don''t fit in, be a writer!
');

insert into eventinfo values(
28,
'The main character in "The Wedding Banquet" learns a couple of
lessons about parents: They can show up at very inconvenient times,
and they always find out if you lie to them.  His predicament arises
from a suprise parental visit in which everyone is a little more
suprised than they had planned to be.  His parents think he''s marrying
a woman, but in reality, he''s living with his male lover.
');

insert into eventinfo values (
27,
'Sponsored by the Africana Student Cultural Center the Universal VIBE
Squad is a positive group of local rappers who seek to enlighten through
the mediums of hip-hop, graffiti and other African-American forms of
communication
');

insert into eventinfo values (
26,
'With special guests John Casey and the Old Possums and Ticks.
-
Like his spirtual brother from across the pond, Irish American Ike Reilly
plays Billy Bragg style folk punk that''s sincere, personal and socially
conscious.  Chicago-based Reilly isn''t afraid to turn up the amps, but
more importantly, he doesn''t pull any punches in the battle between his
ideals and his cynicism. Political punk with a human edge.
');

insert into eventinfo values (
2,
'Coincidences can astound us.  Sometimes carefull thinking can make them
seem less mysterious.  Professor Diaconis will explore examples from
C.G. Jungs work on synchronicity to recent studies of parapsychology.
');

insert into eventinfo values (
3,
'Nuisance or News: A Report Card on the Press
-- 
Louis D. Boccardi, President and CEO, Associated Press
The Annual Silha Lecture, of the Silha Center for the
Study of Media Ethics and Law
');

insert into eventinfo values (
4,
'Frank Gehry, Peter Eisenman, Steven Izenour, Richard Meier, others
-- 
This two-day symposium will examine the recent innovative approaches
to museum architecture by many leading architects, who will be present
to discuss their work.  Public discussions will include architectural
creativity, critical perceptions, the presentation of art and
artifacts, and the role of curators, directors, boards and the public
');

insert into eventinfo values (
13,
'Mr. Jim Reitz, Senior Systems Architect in the Central U.S. for Microsoft,
will do a presentation followed by a "question and answer" session.
-- 
As background, Mr. Reitz is responsible for helping customers understand
Microsofts advanced technology and strategic directions. Jim speaks frequently
at both public events and customer briefings on operating systems, development
tools, connectivity, and corporate applications downsizing.
');

insert into eventinfo values (18,
'The first person account of a very traditional English butler played by
Anthony Hopkins.  A Merchant-Ivory production with Emma Thompson as the
housekeeper.
-- 
local premiere
');

insert into eventinfo values(24,
'Joe Paddock, Minnesota writer, reads from his latest collection of poetry
"Boars Dance."
');

insert into eventinfo values(25,
'Sarah Shulman reads from her new novel Empathy.  In her latest work,
Shulman, a regular contributor to the Village Voice, Nation and Mother
Jones, explores such issues as homophobia, AIDS, homelessness and drugs
');

commit;